==========
Authorship
==========

The following people have contributed to pybdsim:

* Laurie Nevay
* Andrey Abramov
* Siobhan Alden
* Stewart Boogert
* Marin Deniaud
* Cedric Hernalsteens
* Fabian Metzger
* Will Parker
* Eliott Ramoisiaux
* William Shields
* Jochem Snuverink
* Robin Tesse
* Stuart Walker
